# CHANGELOG
## 2.0.8 (2024-06-20)


### :bug: Fixed Bugs

*  update wrap address in template to OZI-Project&amp;emdash; rjdbcm &lt;rjdbcm@outlook.com&gt; ([`030351d`](https://github.com/OZI-Project/ozi-templates/commit/030351d8197881b454007790c237503e3478d58a))


### Other


* :memo: update CHANGELOG and release notes templates&amp;emdash; rjdbcm &lt;rjdbcm@outlook.com&gt; ([`26f02d0`](https://github.com/OZI-Project/ozi-templates/commit/26f02d078ce6ad4874f97c0cba16aa9ee382930d))

## 2.0.7 (2024-06-18)


### :children_crossing: Improved Usability

* CHANGELOG and release_notes templates&amp;emdash; rjdbcm &lt;rjdbcm@outlook.com&gt; ([`fa3ebef`](https://github.com/OZI-Project/ozi-templates/commit/fa3ebefbb148b70150f26f90e90aff274df66178))

## 2.0.6 (2024-06-17)


### :bug: Fixed Bugs

* (checkpoint.yml.j2): prerelease checkpoint no longer included by default&amp;emdash; Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt; ([`124bc74`](https://github.com/OZI-Project/ozi-templates/commit/124bc741ca57781492785fab45d6712eee0a2fd5))


### :children_crossing: Improved Usability

*  Create .gitattributes&amp;emdash; Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt; ([`cf0ba23`](https://github.com/OZI-Project/ozi-templates/commit/cf0ba231f2e911dccf5696c9d5749cc00052f346))

## 2.0.5 (2024-06-17)


### :arrow_up: Upgraded Dependencies

*  Bump ossf/scorecard-action from 2.3.1 to 2.3.3

Bumps [ossf/scorecard-action](https://github.com/ossf/scorecard-action) from 2.3.1 to 2.3.3.
- [Release notes](https://github.com/ossf/scorecard-action/releases)
- [Changelog](https://github.com/ossf/scorecard-action/blob/main/RELEASE.md)
- [Commits](https://github.com/ossf/scorecard-action/compare/0864cf19026789058feabb7e87baa5f140aac736...dc50aa9510b46c811795eb24b2f1ba02a914e534)


updated-dependencies:
- dependency-name: ossf/scorecard-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
...&amp;emdash; dependabot[bot] &lt;support@github.com&gt; ([`b8cc5cf`](https://github.com/OZI-Project/ozi-templates/commit/b8cc5cffb37316b48d63120564e0b4aca5224203))

*  Bump github/codeql-action from 3.25.3 to 3.25.10

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.3 to 3.25.10.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/d39d31e687223d841ef683f52467bd88e9b21c14...23acc5c183826b7a8a97bce3cecc52db901f8251)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
...&amp;emdash; dependabot[bot] &lt;support@github.com&gt; ([`ff5472f`](https://github.com/OZI-Project/ozi-templates/commit/ff5472f9f2b8d10b48bdd4c1fe061da15699e1fe))

*  Bump OZI-Project/draft from 0.3.1 to 0.3.2

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.1 to 0.3.2.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/0.3.1...0.3.2)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
...&amp;emdash; dependabot[bot] &lt;support@github.com&gt; ([`68a5674`](https://github.com/OZI-Project/ozi-templates/commit/68a56749f240cd2a18f42c9f7bb1e8907c1b240f))

*  Bump actions/dependency-review-action from 4.2.5 to 4.3.3

Bumps [actions/dependency-review-action](https://github.com/actions/dependency-review-action) from 4.2.5 to 4.3.3.
- [Release notes](https://github.com/actions/dependency-review-action/releases)
- [Commits](https://github.com/actions/dependency-review-action/compare/5bbc3ba658137598168acb2ab73b21c432dd411b...72eb03d02c7872a771aacd928f3123ac62ad6d3a)


updated-dependencies:
- dependency-name: actions/dependency-review-action
  dependency-type: direct:production
  update-type: version-update:semver-minor
...&amp;emdash; dependabot[bot] &lt;support@github.com&gt; ([`c1498bd`](https://github.com/OZI-Project/ozi-templates/commit/c1498bd797c36a2b03e5dc8a0f7adc5145425f21))

## 2.0.4 (2024-06-17)


### :bug: Fixed Bugs

*  fix PackageLoader path&amp;emdash; rjdbcm &lt;rjdbcm@outlook.com&gt; ([`888050d`](https://github.com/OZI-Project/ozi-templates/commit/888050d270d1ac02ba684ee837b3347d2f2cf310))

## 2.0.3 (2024-06-17)


### :bug: Fixed Bugs

*  fix blastpipe reference in packageloader&amp;emdash; rjdbcm &lt;rjdbcm@outlook.com&gt; ([`2be3d1a`](https://github.com/OZI-Project/ozi-templates/commit/2be3d1a98cd266f85f5fb8e464dc10112f091e27))

## 2.0.2 (2024-06-16)


### :bug: Fixed Bugs

*  fix project module name ([`03f8b1e`](https://github.com/OZI-Project/ozi-templates/commit/03f8b1e630ebf02f513877248ac351436a047c15))

## 2.0.1 (2024-06-16)


### :arrow_up: Upgraded Dependencies

*  OZI-Project/release@0.6.5

Ignores wheel filenames in glob for sigstore.&amp;emdash; Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt; ([`bbe482d`](https://github.com/OZI-Project/ozi-templates/commit/bbe482da512ab78ea4c3ebcdc92a925f4e0525df))

*  bump OZI.build ([`843f161`](https://github.com/OZI-Project/ozi-templates/commit/843f161073077b5bfafcd4f052f9055e256182a2))


### :bug: Fixed Bugs

*  OZI.build&gt;=0.0.26

parity with blastpipe 2024.11.10&amp;emdash; rjdbcm &lt;rjdbcm@outlook.com&gt; ([`b57d4f6`](https://github.com/OZI-Project/ozi-templates/commit/b57d4f67aa1622ddb98ab89540b063f4924a1927))

*  project name ([`1aba880`](https://github.com/OZI-Project/ozi-templates/commit/1aba8809cef1d70bc97ff9497c65cad7b5466242))


### Other


* Update README&amp;emdash; Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt; ([`3efec29`](https://github.com/OZI-Project/ozi-templates/commit/3efec29e2c5efdd4745e202c631649b92f62b049))

* Update meson.build - fix project name&amp;emdash; Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt; ([`95719bf`](https://github.com/OZI-Project/ozi-templates/commit/95719bf0abdee4f4dc7c74a332d115868bf76c3a))

* Fix branch pattern&amp;emdash; Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt; ([`d221e61`](https://github.com/OZI-Project/ozi-templates/commit/d221e618bca32cdf51c7dd26bb58376825d0a05b))

## 2.0.0 (2024-06-16)


### :arrow_up: Upgraded Dependencies

*  Bump step-security/harden-runner from 2.7.0 to 2.8.1

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.7.0 to 2.8.1.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/63c24ba6bd7ba022e95695ff85de572c04a18142...17d0e2bd7d51742c71671bd19fa12bdc9d40a3d6)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-minor
...&amp;emdash; dependabot[bot] &lt;support@github.com&gt; ([`bbc592e`](https://github.com/OZI-Project/ozi-templates/commit/bbc592eb025bdd61ee5003bd554b1f5c04b61702))

*  Bump OZI-Project/checkpoint from 0.1.5 to 0.4.2

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 0.1.5 to 0.4.2.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/0.1.5...0.4.2)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-minor
...&amp;emdash; dependabot[bot] &lt;support@github.com&gt; ([`1ad4dd1`](https://github.com/OZI-Project/ozi-templates/commit/1ad4dd1b02e628b79366f6da2e582bb7ed660dc8))

*  Bump actions/checkout from 4.1.4 to 4.1.7

Bumps [actions/checkout](https://github.com/actions/checkout) from 4.1.4 to 4.1.7.
- [Release notes](https://github.com/actions/checkout/releases)
- [Changelog](https://github.com/actions/checkout/blob/main/CHANGELOG.md)
- [Commits](https://github.com/actions/checkout/compare/0ad4b8fadaa221de15dcec353f45205ec38ea70b...692973e3d937129bcbf40652eb9f2f61becf3332)


updated-dependencies:
- dependency-name: actions/checkout
  dependency-type: direct:production
  update-type: version-update:semver-patch
...&amp;emdash; dependabot[bot] &lt;support@github.com&gt; ([`282d6b9`](https://github.com/OZI-Project/ozi-templates/commit/282d6b96d026d2285e7699169813d853715531d1))


### :boom:


*  version bump&amp;emdash; rjdbcm &lt;rjdbcm@outlook.com&gt; ([`52b4953`](https://github.com/OZI-Project/ozi-templates/commit/52b4953eaaf9427636b4112f5f7378678b2b0a50))

*  fix release strategy ([`e40ebfb`](https://github.com/OZI-Project/ozi-templates/commit/e40ebfb305a64a15aa02f6347d8cb04f633682c3))


### :bug: Fixed Bugs

*  update to build version with normalized metadata&amp;emdash; rjdbcm &lt;rjdbcm@outlook.com&gt; ([`2ccbd1c`](https://github.com/OZI-Project/ozi-templates/commit/2ccbd1c2f0860f690280129b812f9dcb29bf031c))

*  publish if needs.draft.outputs.drafted == &#39;true&#39;&amp;emdash; rjdbcm &lt;rjdbcm@outlook.com&gt; ([`244ddf4`](https://github.com/OZI-Project/ozi-templates/commit/244ddf4c8c74955689ec9a007efa6b09f9e75165))

*  fix repo name&amp;emdash; Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt; ([`959bab3`](https://github.com/OZI-Project/ozi-templates/commit/959bab31da5befd1e651ecb072fa7026e24cc9e9))

*  fix missing tag input to release&amp;emdash; rjdbcm &lt;rjdbcm@outlook.com&gt; ([`a677875`](https://github.com/OZI-Project/ozi-templates/commit/a6778750e5546955daf528f22283bfb77c76fd93))

*  major_on_zero back to false&amp;emdash; rjdbcm &lt;rjdbcm@outlook.com&gt; ([`8e76820`](https://github.com/OZI-Project/ozi-templates/commit/8e76820683aebe3f89f519ec2159ba815de7ca5c))

*  fix missing commit_parser_options&amp;emdash; rjdbcm &lt;rjdbcm@outlook.com&gt; ([`ccf75ef`](https://github.com/OZI-Project/ozi-templates/commit/ccf75ef7f8ccc0cf99329f5a348dc45df84c536e))

*  fix commit_parser name&amp;emdash; rjdbcm &lt;rjdbcm@outlook.com&gt; ([`26b9b7a`](https://github.com/OZI-Project/ozi-templates/commit/26b9b7a61c31170e1e77b6532d9d3ef3448a8505))


### :sparkles: Implemented Features

*  bump version&amp;emdash; rjdbcm &lt;rjdbcm@outlook.com&gt; ([`83c01e5`](https://github.com/OZI-Project/ozi-templates/commit/83c01e5f8def35badc58f7b00bba58b2fa547c94))

*  revert angular commit parsing.&amp;emdash; rjdbcm &lt;rjdbcm@outlook.com&gt; ([`1a8e395`](https://github.com/OZI-Project/ozi-templates/commit/1a8e3958989ed760de0494faef3c48797d13b3e4))


### Other


* Update pyproject.toml&amp;emdash; Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt; ([`178143e`](https://github.com/OZI-Project/ozi-templates/commit/178143e956bb251585181c680d1278b99cc98650))

* Update pyproject.toml&amp;emdash; Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt; ([`f4b6b38`](https://github.com/OZI-Project/ozi-templates/commit/f4b6b38ad98c1e22df02cf45c758fa7d664cd4ee))

* Update pyproject.toml&amp;emdash; Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt; ([`63eb260`](https://github.com/OZI-Project/ozi-templates/commit/63eb260f9e4a916d80d226b890f385ee1fd463ad))

* fix(semantic-release): config ``major_on_zero = true``&amp;emdash; rjdbcm &lt;rjdbcm@outlook.com&gt; ([`e2e04ef`](https://github.com/OZI-Project/ozi-templates/commit/e2e04efdf3d1d93868d3d1653f547427e5b63b18))

* fix(readme-renderer): fix args to target readme copied during build&amp;emdash; rjdbcm &lt;rjdbcm@outlook.com&gt; ([`d7ed57f`](https://github.com/OZI-Project/ozi-templates/commit/d7ed57f81d679006b0cf8125ee92d68b541e15de))

* style(isort): import sort&amp;emdash; rjdbcm &lt;rjdbcm@outlook.com&gt; ([`fad659c`](https://github.com/OZI-Project/ozi-templates/commit/fad659c29b487e507396522e5edbb08923444ca8))

* fix(dist-depends): restore requirements.in&amp;emdash; rjdbcm &lt;rjdbcm@outlook.com&gt; ([`3586f0f`](https://github.com/OZI-Project/ozi-templates/commit/3586f0f033a1f0d52c680c7964a5ab3b1ec8b006))

* fix(imports): remove blastpipe references&amp;emdash; rjdbcm &lt;rjdbcm@outlook.com&gt; ([`97395ae`](https://github.com/OZI-Project/ozi-templates/commit/97395ae610647f20909152613dbd927447dc418b))

* fix(tests): add test_filter.py to build&amp;emdash; rjdbcm &lt;rjdbcm@outlook.com&gt; ([`9b99d3a`](https://github.com/OZI-Project/ozi-templates/commit/9b99d3a060de90f41f12509e68f5b50f12705a08))

* style(isort): sort imports&amp;emdash; rjdbcm &lt;rjdbcm@outlook.com&gt; ([`6faeeff`](https://github.com/OZI-Project/ozi-templates/commit/6faeeffed15231f5f3ac6f2f8628e78b430081d6))

* Update pyproject.toml&amp;emdash; Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt; ([`8dfad97`](https://github.com/OZI-Project/ozi-templates/commit/8dfad9728cb2934c388714f1e9a968000993dcd1))

* feat(package): mirror blastpipe 2024.11.7 ozi_templates&amp;emdash; rjdbcm &lt;rjdbcm@outlook.com&gt; ([`2987d9c`](https://github.com/OZI-Project/ozi-templates/commit/2987d9c6b8ebc723ed3dc39334794c7fd764709a))

## 1.0.0 (2024-04-27)


### :boom:


*  add load_environment() func&amp;emdash; rjdbcm &lt;rjdbcm@mail.umkc.edu&gt; ([`7cb9510`](https://github.com/OZI-Project/ozi-templates/commit/7cb951045f3855ab6a301ca52d536d96e4a3f0c0))


### :bug: Fixed Bugs

*  fix release workflow outputs so publish is not skipped.&amp;emdash; rjdbcm &lt;rjdbcm@outlook.com&gt; ([`2ce8dd0`](https://github.com/OZI-Project/ozi-templates/commit/2ce8dd0f24f52f9c497dd9dd57be6bdcd917b010))

*  Fix publish workflow had ssh arguments still.&amp;emdash; rjdbcm &lt;rjdbcm@outlook.com&gt; ([`77a8ede`](https://github.com/OZI-Project/ozi-templates/commit/77a8edef6915fc3324e0ac131500747a5a8d72f1))

*  fix name normalization in project and template.

Without normalization we get duplicate dist_info.&amp;emdash; rjdbcm &lt;rjdbcm@outlook.com&gt; ([`d40e46a`](https://github.com/OZI-Project/ozi-templates/commit/d40e46ae36927546cca0fe76baa2c870ccd6a2a7))


### :fire: Deleted Code or Files

*  delete template readme ([`33abd6c`](https://github.com/OZI-Project/ozi-templates/commit/33abd6c51075136fb8b40ba7c81e28a2b405f236))


### :pencil2: Corrected Typos

*  correct project name ([`9df80d8`](https://github.com/OZI-Project/ozi-templates/commit/9df80d8511050ab6596f5b10f8d7dc41be0c0924))


### Other


* Initial clone of templates&amp;emdash; rjdbcm &lt;rjdbcm@mail.umkc.edu&gt; ([`a8370f9`](https://github.com/OZI-Project/ozi-templates/commit/a8370f94cf621f3035ce6ac956fe96a752b005d2))

* Bump github/codeql-action from 3.25.2 to 3.25.3

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.2 to 3.25.3.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/8f596b4ae3cb3c588a5c46780b86dd53fef16c52...d39d31e687223d841ef683f52467bd88e9b21c14)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
...&amp;emdash; dependabot[bot] &lt;support@github.com&gt; ([`54566b3`](https://github.com/OZI-Project/ozi-templates/commit/54566b3f685b0a8757105c1ff8177eabdbe61d3e))

* Initial commit ([`6df66d3`](https://github.com/OZI-Project/ozi-templates/commit/6df66d3a74d25f7e06bb573249b8c065155b9358))
